CurveDatum class

Constructors

CurveDatum({int? serNum, int? targetUnitType, double? barSet, double? flowSet, double? timeSet, double? weightSet, int? intervalTime})
CurveDatum.fromJson(Map<String, dynamic> json)
factory

Properties

barSet ↔ double?
getter/setter pair
flowSet ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intervalTime ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serNum ↔ int?
getter/setter pair
targetUnitType ↔ int?
getter/setter pair
timeSet ↔ double?
getter/setter pair
weightSet ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited