CipherUtil class

Constructors

CipherUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

base64Decode(String cipher) → String
encodeBase64(String data) → String
generateRandomString(int length) → String
generateSignature(int timestamp, String messageId) → String
generateSignature2(Map<String, dynamic> paramValues, List<String> ignoreParamNames, String appSecret) → String
生成sign校验值 paramValues 参数值 ignoreParamNames 要忽略掉的参数名 appSecret appSecret @return